# Table of Contents

- [metrics](<./metrics.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Metrics](<./Metrics.md>)
  - [Overview](<./Metrics/Overview.md>)
  - [Creating a Chart](<./Metrics/Creating-a-Chart.md>)
  - [Developer Resources](<./Metrics/Developer-Resources.md>)
  - [Definitions](<./Metrics/Definitions.md>)
  - [Importing a Metric](<./Metrics/Importing-a-Metric.md>)
  - [Using Python to Import Metrics](<./Metrics/Using-Python-to-Import-Metrics.md>)
  - [API Documentation](<./Metrics/API-Documentation.md>)
  - [Using the Integration API](<./Metrics/Using-the-Integration-API.md>)
  - [Steps to Create Integration](<./Metrics/Steps-to-Create-Integration.md>)
